## Release Notes for 1.1.1

Released on 21 February 2021

This patch makes a couple of minor improvements to the GUI. The keyboard shortcut for deleting entries in the project tree has been changed from "Ctrl+Del" to "Ctrl+Shift+Del" to free up that shortcut for the document editor. It is now possible to use the shortcut for deleting the word in front of the cursor, a common and useful feature of many text editors.

The way the negative word count filter option works on the Writing Statistics tool has been changed to be more intuitive. Enabling this filter now appears to remove all negative entries without altering the other entries. Previously, the removed negative counts would be included in the following entries to make it consistent with the total word count. In addition, writing sessions shorter than five minutes, and with no change in the word count, are no longer recorded in the session log file.

Other changes include improving the speed of the internal spell checker, used when the Enchant spell check library isn't available. The internal spell checker is no longer significantly slower, but is still lacking in functionality compared to Enchant.

See also the Releases page.

## Release Notes for 1.1

Released on 7 February 2021

The main change in this release is the addition of a new tab to the project tree on the left side of the main window. The regular project tree is now on a tab named "Project", while a new tab named "Novel" displays a simpler version of the information on the main "Outline" page. It lists all the headers of the novel part of the project, as well as the word count and point-of-view character of each section. This is an alternative way to navigate the novel part of the project. The various tree views are now also kept better in sync when the user selects various documents and headers.

In addition, a new information dialog named "Project Details" has been added. It replaces the "Details" tab in "Project Settings", and adds more information about the novel part of the project. In particular, a "Table of Contents" in the "Contents" tab displays a summary of the main parts and chapters of the project, their total word counts, and an estimated page count. This was made in response to users asking for ways to estimate the total page count of the project. The page count is estimated based on a words per page setting, which can be changed on the dialog window.

Since the tabs below the project tree now add some extra room on the GUI, some convenient buttons have been added in the same area, with direct access to "Project Details", "Writing Statistics" and "Project Setting".

A few other minor changes have been made as well. The Preferences dialog has been improved with clearer categories and hopefully better help text. Some new options have been added too. They allow syntax highlighting of multi-paragraph quotes. The highlighter can now optionally accept quotes to be left "hanging", that is, no closing quote in the same paragraph.